@@ -1,9 +1,10 @@
 from vidispine.base import EntityBase
 from vidispine.errors import InvalidInput
+from vidispine.metadata import MetadataMixin
 from vidispine.typing import BaseJson
 
 
-class Item(EntityBase):
+class Item(MetadataMixin, EntityBase):
     """Items
 
     Manage items.
@@ -29,8 +30,7 @@ class Item(EntityBase):
         :rtype: vidispine.typing.BaseJson.
 
         """
-
-        if not params:
+        if params is None:
             params = {}
 
         if metadata:
@@ -109,6 +109,33 @@ class ItemShape(EntityBase):
 
     entity = 'item'
 
+    def create(
+        self,
+        metadata: dict,
+        item_id: str,
+        params: dict = None
+    ) -> BaseJson:
+        """Creates a new shape using the supplied information.
+
+        :param metadata: Metadata (shape document) to create the shape
+            with.
+        :param item_id: The ID of the item.
+        :param params: Optional query parameters.
+
+        :return: JSON response from the request.
+        :rtype: vidispine.typing.BaseJson.
+
+        """
+        if not metadata:
+            raise InvalidInput('Please supply metadata.')
+
+        if params is None:
+            params = {}
+
+        endpoint = self._build_url(f'{item_id}/shape/create')
+
+        return self.client.post(endpoint, json=metadata, params=params)
+
     def get(
         self,
         item_id: str,
@@ -125,7 +152,6 @@ class ItemShape(EntityBase):
         :rtype: vidispine.typing.BaseJson.
 
         """
-
         if params is None:
             params = {}
 
@@ -143,7 +169,6 @@ class ItemShape(EntityBase):
         :rtype: vidispine.typing.BaseJson.
 
         """
-
         if params is None:
             params = {}
 
@@ -159,7 +184,6 @@ class ItemShape(EntityBase):
         :param params: Optional query parameters.
 
         """
-
         if params is None:
             params = {}
 
@@ -167,6 +191,20 @@ class ItemShape(EntityBase):
 
         self.client.delete(endpoint, params=params)
 
+    def delete_all(self, item_id: str, params: dict = None) -> None:
+        """Removes all shapes from an item.
+
+        :param item_id: The ID of the item.
+        :param params: Optional query parameters.
+
+        """
+        if params is None:
+            params = {}
+
+        endpoint = self._build_url(f'{item_id}/shape')
+
+        self.client.delete(endpoint, params=params)
+
     def import_shape(self, item_id: str, params: dict) -> None:
         """Starts a new shape import job.
 
